%global __cmake_in_source_build 1

Summary:        The MariaDB Native Client library (C driver)
Name:           mariadb-connector-c
Version:        3.3.5
Release:        5%{?dist}
License:        LGPLv2+
Url:            https://github.com/MariaDB/mariadb-connector-c
Source0:        https://archive.mariadb.org/connector-c-%{version}/%{name}-%{version}-src.tar.gz
Source2:        my.cnf
Source3:        client.cnf

BuildRequires:  gcc-c++, cmake
BuildRequires:  libcurl-devel, zlib-devel libzstd-devel
BuildRequires:  krb5-devel, openssl-devel
Requires:       %{_sysconfdir}/my.cnf

%description
The MariaDB Native Client library (C driver) is used to connect applications
developed in C/C++ to MariaDB and MySQL databases.

%package devel
Summary:        Development files for mariadb-connector-c
Requires:       %{name} = %{version}-%{release}
Requires:       openssl-devel zlib-devel

%description devel
Development files for mariadb-connector-c.
Contains everything needed to build against libmariadb.so >=3 client library.

%package config
Summary:        Configuration files for packages that use /etc/my.cnf as a configuration file
BuildArch:      noarch

%description config
This package provides /etc/my.cnf that includes other configuration files from the /etc/my.cnf.d 
directory and ships this directory as well.
Other packages should only put their files into /etc/my.cnf.d directory and require this package, 
so the /etc/my.cnf file is present.

%prep
%autosetup -n %{name}-%{version}-src

%build
%cmake . \
       -DCMAKE_SYSTEM_PROCESSOR="%{_arch}" \
       -DMARIADB_PORT=3306 \
       -DWITH_EXTERNAL_ZLIB=ON \
       -DWITH_SSL=OPENSSL \
       -DWITH_MYSQLCOMPAT=ON \
       -DPLUGIN_CLIENT_ED25519=DYNAMIC \
       -DINSTALL_LAYOUT=RPM \
       -DINSTALL_LIBDIR="%{_lib}" \
       -DINSTALL_INCLUDEDIR="include/mysql" \
       -DINSTALL_PLUGINDIR="%{_lib}/mariadb/plugin" \
       -DINSTALL_PCDIR="%{_lib}/pkgconfig" \
       -DMARIADB_UNIX_ADDR=%{_sharedstatedir}/mysql/mysql.sock \
       -DWITH_UNIT_TESTS=ON
%cmake_build

%install
%cmake_install

rm %{buildroot}%{_libdir}/lib*.a
ln -s mariadb_config %{buildroot}%{_bindir}/mysql_config
ln -s mariadb_version.h %{buildroot}%{_includedir}/mysql/mysql_version.h

# Install config files
install -D -p -m 0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/my.cnf
install -D -p -m 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/my.cnf.d/client.cnf

%check
%{buildroot}%{_bindir}/mariadb_config

%ctest --test-dir %{__cmake_builddir}/unittest/libmariadb/ || :


%files
%license COPYING.LIB
%doc README
%{_libdir}/libmariadb.so.3
%dir %{_libdir}/mariadb
%dir %{_libdir}/mariadb/plugin
%{_libdir}/mariadb/plugin/*
%{_mandir}/man3/*

%files devel
%{_bindir}/mariadb_config
%{_bindir}/mysql_config
%{_libdir}/libmariadb.so
%{_libdir}/libmysqlclient.so
%{_libdir}/libmysqlclient_r.so
%{_libdir}/pkgconfig/libmariadb.pc
%dir %{_includedir}/mysql
%{_includedir}/mysql/*

%files config
%dir %{_sysconfdir}/my.cnf.d
%config(noreplace) %{_sysconfdir}/my.cnf
%config(noreplace) %{_sysconfdir}/my.cnf.d/client.cnf

%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.3.5-5
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.3.5-4
- Rebuilt for loongarch release

* Thu Oct 12 2023 Miaojun Dong <zoedong@tencent.com> - 3.3.5-3
- Rebuild for curl-8.4.0

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.3.5-2
- Rebuilt for OpenCloudOS Stream 23.09

* Thu Aug 17 2023 Wang Guodong <gordonwwang@tencent.com> - 3.3.5-1
- Upgrade to version 3.3.5

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.3.1-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.3.1-3
- Rebuilt for OpenCloudOS Stream 23

* Thu Dec 15 2022 Wang Guodong <gordonwwang@tencent.com> - 3.3.1-2
- Add the config subpackage.

* Mon Jul 18 2022 cunshunxia <cunshunxia@tencent.com> - 3.3.1-1
- initial build
